@@ -34,8 +34,6 @@
 
 int readentropy(void *out, size_t outsize);
 
-void fill_with_repeating_pattern(void *out, size_t outsize);
-
 void make_cookie(char *);
 
 int is_closed(int);
@@ -53,9 +51,8 @@ const char* get_system_info(void);
 const char* get_optional_features(void);
 
 cJSON* iperf_json_printf(const char *format, ...);
-cJSON * iperf_cJSON_GetObjectItemType(cJSON * j_p, char * item_string, int expected_type);
 
-void iperf_dump_fdset(FILE *fp, const char *str, int nfds, fd_set *fds);
+void iperf_dump_fdset(FILE *fp, char *str, int nfds, fd_set *fds);
 
 #ifndef HAVE_DAEMON
 extern int daemon(int nochdir, int noclose);
@@ -65,6 +62,4 @@ extern int daemon(int nochdir, int noclose);
 ssize_t getline(char **buf, size_t *bufsiz, FILE *fp);
 #endif /* HAVE_GETLINE */
 
-char * state_to_text(signed char state);
-
 #endif
